@@ -2,7 +2,7 @@
 * simple_prefs.m: Simple Preferences for Mac OS X
 *****************************************************************************
 * Copyright (C) 2008-2009 the VideoLAN team
-* $Id: 785541932e71546287e5e71df29be7b218ba85d1 $
+* $Id: a38642901785e97a4d83587ea0f4630ec8d19215 $
 *
 * Authors: Felix Paul Kühne <fkuehne at videolan dot org>
 *
@@ -27,7 +27,9 @@
 #import <vlc_interface.h>
 #import <vlc_dialog.h>
 #import "misc.h"
+#import "intf.h"
 #import "AppleRemote.h"
+#import <Sparkle/Sparkle.h>                        //for o_intf_last_update_lbl
 
 static NSString* VLCSPrefsToolbarIdentifier = @"Our Simple Preferences Toolbar Identifier";
 static NSString* VLCIntfSettingToolbarIdentifier = @"Intf Settings Item Identifier";
@@ -84,9 +86,12 @@ static VLCSimplePrefs *_o_sharedInstance = nil;
     if( val & KEY_MODIFIER_COMMAND )
         [o_temp_str appendString: [NSString stringWithUTF8String: "\xE2\x8C\x98"]];
 
-    const char *base = KeyToString( val & ~KEY_MODIFIER );
+    char *base = KeyToString( val & ~KEY_MODIFIER );
     if( base )
+    {
         [o_temp_str appendString: [NSString stringWithUTF8String: base]];
+        free( base );
+    }
     else
         o_temp_str = [NSMutableString stringWithString:_NS("Not Set")];
     return o_temp_str;
@@ -95,7 +100,7 @@ static VLCSimplePrefs *_o_sharedInstance = nil;
 - (void)awakeFromNib
 {
     [self initStrings];
-    
+
     /* setup the toolbar */
     NSToolbar * o_sprefs_toolbar = [[[NSToolbar alloc] initWithIdentifier: VLCSPrefsToolbarIdentifier] autorelease];
     [o_sprefs_toolbar setAllowsUserCustomization: NO];
@@ -104,7 +109,7 @@ static VLCSimplePrefs *_o_sharedInstance = nil;
     [o_sprefs_toolbar setSizeMode: NSToolbarSizeModeRegular];
     [o_sprefs_toolbar setDelegate: self];
     [o_sprefs_win setToolbar: o_sprefs_toolbar];
-    
+
     /* setup useful stuff */
     o_hotkeysNonUseableKeys = [[NSArray arrayWithObjects:
                                 [NSNumber numberWithInt: KEY_MODIFIER_COMMAND|'c'],
@@ -164,8 +169,8 @@ create_toolbar_item( NSString * o_itemIdent, NSString * o_name, NSString * o_des
     return o_toolbarItem;
 }
 
-- (NSToolbarItem *) toolbar: (NSToolbar *)o_sprefs_toolbar 
-      itemForItemIdentifier: (NSString *)o_itemIdent 
+- (NSToolbarItem *) toolbar: (NSToolbar *)o_sprefs_toolbar
+      itemForItemIdentifier: (NSString *)o_itemIdent
   willBeInsertedIntoToolbar: (BOOL)b_willBeInserted
 {
     NSToolbarItem *o_toolbarItem = nil;
@@ -200,19 +205,19 @@ create_toolbar_item( NSString * o_itemIdent, NSString * o_name, NSString * o_des
 
 - (NSArray *)toolbarDefaultItemIdentifiers: (NSToolbar *)toolbar
 {
-    return [NSArray arrayWithObjects: VLCIntfSettingToolbarIdentifier, VLCAudioSettingToolbarIdentifier, VLCVideoSettingToolbarIdentifier, 
+    return [NSArray arrayWithObjects: VLCIntfSettingToolbarIdentifier, VLCAudioSettingToolbarIdentifier, VLCVideoSettingToolbarIdentifier,
         VLCOSDSettingToolbarIdentifier, VLCInputSettingToolbarIdentifier, VLCHotkeysSettingToolbarIdentifier, NSToolbarFlexibleSpaceItemIdentifier, nil];
 }
 
 - (NSArray *)toolbarAllowedItemIdentifiers: (NSToolbar *)toolbar
 {
-    return [NSArray arrayWithObjects: VLCIntfSettingToolbarIdentifier, VLCAudioSettingToolbarIdentifier, VLCVideoSettingToolbarIdentifier, 
+    return [NSArray arrayWithObjects: VLCIntfSettingToolbarIdentifier, VLCAudioSettingToolbarIdentifier, VLCVideoSettingToolbarIdentifier,
         VLCOSDSettingToolbarIdentifier, VLCInputSettingToolbarIdentifier, VLCHotkeysSettingToolbarIdentifier, NSToolbarFlexibleSpaceItemIdentifier, nil];
 }
 
 - (NSArray *)toolbarSelectableItemIdentifiers:(NSToolbar *)toolbar
 {
-    return [NSArray arrayWithObjects: VLCIntfSettingToolbarIdentifier, VLCAudioSettingToolbarIdentifier, VLCVideoSettingToolbarIdentifier, 
+    return [NSArray arrayWithObjects: VLCIntfSettingToolbarIdentifier, VLCAudioSettingToolbarIdentifier, VLCVideoSettingToolbarIdentifier,
         VLCOSDSettingToolbarIdentifier, VLCInputSettingToolbarIdentifier, VLCHotkeysSettingToolbarIdentifier, nil];
 }
 
@@ -266,6 +271,8 @@ create_toolbar_item( NSString * o_itemIdent, NSString * o_name, NSString * o_des
 	[o_intf_appleremote_ckb setTitle: _NS("Control playback with the Apple Remote")];
 	[o_intf_mediakeys_ckb setTitle: _NS("Control playback with media keys")];
     [o_intf_mediakeys_bg_ckb setTitle: _NS("...when VLC is in background")];
+    [o_intf_update_ckb setTitle: _NS("Automatically check for updates")];
+    [o_intf_last_update_lbl setStringValue: @""];
 
     /* Subtitles and OSD */
     [o_osd_encoding_txt setStringValue: _NS("Default Encoding")];
@@ -294,7 +301,7 @@ create_toolbar_item( NSString * o_itemIdent, NSString * o_name, NSString * o_des
     [o_video_snap_format_txt setStringValue: _NS("Format")];
     [o_video_snap_prefix_txt setStringValue: _NS("Prefix")];
     [o_video_snap_seqnum_ckb setTitle: _NS("Sequential numbering")];
-    
+
     /* generic stuff */
     [[o_sprefs_basicFull_matrix cellAtRow: 0 column: 0] setStringValue: _NS("Basic")];
     [[o_sprefs_basicFull_matrix cellAtRow: 0 column: 1] setStringValue: _NS("All")];
@@ -351,10 +358,10 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
         }
         else if( p_item->ppsz_list[i] )
             mi = [[NSMenuItem alloc] initWithTitle: [NSString stringWithUTF8String: p_item->ppsz_list[i]] action:NULL keyEquivalent: @""];
-        else 
-            msg_Err( VLCIntf, "item %d of pref %s failed to be created", i, name);
+        else
+            msg_Err( p_intf, "item %d of pref %s failed to be created", i, name );
         [mi setRepresentedObject:[NSString stringWithUTF8String: p_item->ppsz_list[i]]];
-        [[object menu] addItem: mi];
+        [[object menu] addItem: [mi autorelease]];
         if( p_item->value.psz && !strcmp( p_item->value.psz, p_item->ppsz_list[i] ) )
             [object selectItem:[object lastItem]];
     }
@@ -378,7 +385,8 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
             mi = [[NSMenuItem alloc] initWithTitle: _NS( p_item->ppsz_list_text[i] ) action:NULL keyEquivalent: @""];
         else if( p_item->pi_list[i] )
             mi = [[NSMenuItem alloc] initWithTitle: [NSString stringWithFormat: @"%d", p_item->pi_list[i]] action:NULL keyEquivalent: @""];
-        else NSLog( @"item %d of pref %s failed to be created", i, name);
+        else
+            msg_Err( p_intf, "item %d of pref %s failed to be created", i, name);
         [mi setRepresentedObject:[NSNumber numberWithInt: p_item->pi_list[i]]];
         [[object menu] addItem: [mi autorelease]];
         if( p_item->value.i == p_item->pi_list[i] )
@@ -392,15 +400,15 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
     module_config_t *p_item;
     module_t *p_parser, **p_list;
     int y = 0;
-    
+
     [object removeAllItems];
-    
+
     p_item = config_FindConfig( VLC_OBJECT(p_intf), name );
     p_list = module_list_get( NULL );
     if( !p_item ||!p_list )
     {
         if( p_list ) module_list_free(p_list);
-        NSLog( @"serious problem, item or list not found" );
+        msg_Err( p_intf, "serious problem, item or list not found" );
         return;
     }
 
@@ -441,7 +449,7 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
 
     [[o_sprefs_basicFull_matrix cellAtRow:0 column:0] setState: NSOnState];
     [[o_sprefs_basicFull_matrix cellAtRow:0 column:1] setState: NSOffState];
-    
+
     /**********************
      * interface settings *
      **********************/
@@ -454,6 +462,10 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
 	[self setupButton: o_intf_mediakeys_ckb forBoolValue: "macosx-mediakeys"];
     [self setupButton: o_intf_mediakeys_bg_ckb forBoolValue: "macosx-mediakeys-background"];
     [o_intf_mediakeys_bg_ckb setEnabled: [o_intf_mediakeys_ckb state]];
+    if( [[SUUpdater sharedUpdater] lastUpdateCheckDate] != NULL )
+        [o_intf_last_update_lbl setStringValue: [NSString stringWithFormat: _NS("Last check on: %@"), [[[SUUpdater sharedUpdater] lastUpdateCheckDate] descriptionWithLocale: [[NSUserDefaults standardUserDefaults] dictionaryRepresentation]]]];
+    else
+        [o_intf_last_update_lbl setStringValue: _NS("No check was performed yet.")];
 
     /******************
      * audio settings *
@@ -526,7 +538,7 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
     while( i < y )
     {
         NSRect s_rect = [[[NSScreen screens] objectAtIndex: i] frame];
-        [o_video_device_pop addItemWithTitle: 
+        [o_video_device_pop addItemWithTitle:
          [NSString stringWithFormat: @"%@ %i (%ix%i)", _NS("Screen"), i+1,
                    (int)s_rect.size.width, (int)s_rect.size.height]];
         [[o_video_device_pop lastItem] setTag: (int)[[[NSScreen screens] objectAtIndex: i] displayID]];
@@ -556,7 +568,7 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
     [self setupButton: o_input_skipLoop_pop forIntList: "ffmpeg-skiploopfilter"];
 
     [o_input_cachelevel_pop removeAllItems];
-    [o_input_cachelevel_pop addItemsWithTitles: 
+    [o_input_cachelevel_pop addItemsWithTitles:
         [NSArray arrayWithObjects: _NS("Custom"), _NS("Lowest latency"), _NS("Low latency"), _NS("Normal"),
             _NS("High latency"), _NS("Higher latency"), nil]];
     [[o_input_cachelevel_pop itemAtIndex: 0] setTag: 0];
@@ -565,7 +577,7 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
     [[o_input_cachelevel_pop itemAtIndex: 3] setTag: 300];
     [[o_input_cachelevel_pop itemAtIndex: 4] setTag: 400];
     [[o_input_cachelevel_pop itemAtIndex: 5] setTag: 500];
-    
+
 #define TestCaC( name ) \
     b_cache_equal =  b_cache_equal && \
         ( i_cache == config_GetInt( p_intf, name ) )
@@ -577,7 +589,7 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
     /* Select the accurate value of the PopupButton */
     bool b_cache_equal = true;
     int i_cache = config_GetInt( p_intf, "file-caching");
-    
+
     TestCaC( "udp-caching" );
     if( module_exists ("dvdread") )
         TestCaC( "dvdread-caching" );
@@ -609,23 +621,24 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
      * subtitle settings *
      *********************/
     [self setupButton: o_osd_osd_ckb forBoolValue: "osd"];
-    
+
     [self setupButton: o_osd_encoding_pop forStringList: "subsdec-encoding"];
     [self setupField: o_osd_lang_fld forOption: "sub-language" ];
-	
+
 	if( module_exists( "quartztext" ) )
 	{
 		[self setupField: o_osd_font_fld forOption: "quartztext-font"];
 		[self setupButton: o_osd_font_color_pop forIntList: "quartztext-color"];
 		[self setupButton: o_osd_font_size_pop forIntList: "quartztext-rel-fontsize"];
 	}
-	else 
+	else
 	{
         /* fallback on freetype */
-        [o_osd_font_fld setEditable: YES];
 		[self setupField: o_osd_font_fld forOption: "freetype-font"];
 		[self setupButton: o_osd_font_color_pop forIntList: "freetype-color"];
 		[self setupButton: o_osd_font_size_pop forIntList: "freetype-rel-fontsize"];
+		/* selector button is useless in this case */
+		[o_osd_font_btn setEnabled: NO];
 	}
 
 
@@ -657,19 +670,17 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
 
 - (void)showSimplePrefs
 {
-    NSAutoreleasePool *o_pool = [[NSAutoreleasePool alloc] init];
     /* we want to show the interface settings, if no category was chosen */
     if( [[o_sprefs_win toolbar] selectedItemIdentifier] == nil )
     {
         [[o_sprefs_win toolbar] setSelectedItemIdentifier: VLCIntfSettingToolbarIdentifier];
         [self showInterfaceSettings];
     }
-    
+
     [self resetControls];
 
     [o_sprefs_win center];
     [o_sprefs_win makeKeyAndOrderFront: self];
-    [o_pool release];
 }
 
 - (IBAction)buttonAction:(id)sender
@@ -698,7 +709,7 @@ static inline char * __config_GetLabel( vlc_object_t *p_this, const char *psz_na
         msg_Warn( p_intf, "unknown buttonAction sender" );
 }
 
-- (void)sheetDidEnd:(NSWindow *)o_sheet 
+- (void)sheetDidEnd:(NSWindow *)o_sheet
          returnCode:(int)i_return
         contextInfo:(void *)o_context
 {
@@ -730,7 +741,6 @@ static inline void save_string_list( intf_thread_t * p_intf, id object, const ch
     if( p_stringobject )
     {
         config_PutPsz( p_intf, name, [p_stringobject UTF8String] );
-        [p_stringobject release];
     }
 }
 
@@ -764,9 +774,9 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
 {
     char *psz_tmp;
     int i;
-    
+
 #define SaveIntList( object, name ) save_int_list( p_intf, object, name )
-                    
+
 #define SaveStringList( object, name ) save_string_list( p_intf, object, name )
 
 #define SaveModuleList( object, name ) save_module_list( p_intf, object, name )
@@ -781,7 +791,7 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
 
         config_PutInt( p_intf, "macosx-fspanel", [o_intf_fspanel_ckb state] );
         config_PutInt( p_intf, "embedded-video", [o_intf_embedded_ckb state] );
-        config_PutInt( p_intf, "macosx-appleremote", [o_intf_appleremote_ckb state] );
+		config_PutInt( p_intf, "macosx-appleremote", [o_intf_appleremote_ckb state] );
 		config_PutInt( p_intf, "macosx-mediakeys", [o_intf_mediakeys_ckb state] );
         config_PutInt( p_intf, "macosx-mediakeys-background", [o_intf_mediakeys_bg_ckb state] );
 
@@ -790,7 +800,7 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
 			[[[VLCMain sharedInstance] appleRemoteController] startListening: [VLCMain sharedInstance]];
 		else
 			[[[VLCMain sharedInstance] appleRemoteController] stopListening: [VLCMain sharedInstance]];
-        [[NSNotificationCenter defaultCenter] postNotificationName: @"VLCMediaKeySupportSettingChanged" 
+        [[NSNotificationCenter defaultCenter] postNotificationName: @"VLCMediaKeySupportSettingChanged"
                                                             object: nil
                                                           userInfo: nil];
 
@@ -808,7 +818,7 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
 
         b_intfSettingChanged = NO;
     }
-    
+
     /******************
      * audio settings *
      ******************/
@@ -816,7 +826,6 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
     {
         config_PutInt( p_intf, "audio", [o_audio_enable_ckb state] );
         config_PutInt( p_intf, "volume", ([o_audio_vol_sld intValue] * 2.56));
-        NSLog( @"slider=%i, pref=%i", [o_audio_vol_sld intValue], config_GetInt( p_intf, "volume" ));
         config_PutInt( p_intf, "spdif", [o_audio_spdif_ckb state] );
 
         SaveIntList( o_audio_dolby_pop, "force-dolby-surround" );
@@ -855,7 +864,7 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
 
         /* Last.FM is optional */
         if( module_exists( "audioscrobbler" ) )
-        {   
+        {
             [o_audio_last_ckb setEnabled: YES];
             if( [o_audio_last_ckb state] == NSOnState )
                 config_AddIntf( p_intf, "audioscrobbler" );
@@ -878,12 +887,12 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
             msg_Err( p_intf, "An error occurred while saving the Audio settings using SimplePrefs (%i)", i );
             dialog_Fatal( p_intf, _("Audio Settings not saved"),
                         _("An error occured while saving your settings via SimplePrefs (%i)."), i );
-            
+
             i = 0;
         }
         b_audioSettingChanged = NO;
     }
-    
+
     /******************
      * video settings *
      ******************/
@@ -915,7 +924,7 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
         }
         b_videoSettingChanged = NO;
     }
-    
+
     /***************************
      * input & codecs settings *
      ***************************/
@@ -981,20 +990,21 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
         }
         b_inputSettingChanged = NO;
     }
-    
+
     /**********************
      * subtitles settings *
      **********************/
     if( b_osdSettingChanged )
     {
         config_PutInt( p_intf, "osd", [o_osd_osd_ckb state] );
+
         if( [o_osd_encoding_pop indexOfSelectedItem] >= 0 )
             SaveStringList( o_osd_encoding_pop, "subsdec-encoding" );
         else
             config_PutPsz( p_intf, "subsdec-encoding", "" );
 
         config_PutPsz( p_intf, "sub-language", [[o_osd_lang_fld stringValue] UTF8String] );
-        
+
 		if( module_exists( "quartztext" ) )
 		{
 			config_PutPsz( p_intf, "quartztext-font", [[o_osd_font_fld stringValue] UTF8String] );
@@ -1006,7 +1016,7 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
             /* fallback on freetype */
 			config_PutPsz( p_intf, "freetype-font", [[o_osd_font_fld stringValue] UTF8String] );
 			SaveIntList( o_osd_font_color_pop, "freetype-color" );
-			SaveIntList( o_osd_font_size_pop, "freetype-rel-fontsize" );                
+			SaveIntList( o_osd_font_size_pop, "freetype-rel-fontsize" );
 		}
 
         i = config_SaveConfigFile( p_intf, NULL );
@@ -1020,7 +1030,7 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
         }
         b_osdSettingChanged = NO;
     }
-    
+
     /********************
      * hotkeys settings *
      ********************/
@@ -1032,7 +1042,7 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
         {
             config_PutInt( p_intf, p_hotkeys[i].psz_action, [[o_hotkeySettings objectAtIndex: i-1] intValue] );
             i++;
-        }        
+        }
 
         i = config_SaveConfigFile( p_intf, "main" );
 
@@ -1052,7 +1062,7 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
     NSRect o_win_rect, o_view_rect, o_old_view_rect;
     o_win_rect = [o_sprefs_win frame];
     o_view_rect = [o_new_category_view frame];
-    
+
     if( o_currentlyShownCategoryView != nil )
     {
         /* restore our window's height, if we've shown another category previously */
@@ -1063,20 +1073,20 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
         /* remove our previous category view */
         [o_currentlyShownCategoryView removeFromSuperviewWithoutNeedingDisplay];
     }
-    
+
     o_win_rect.size.height = o_win_rect.size.height + o_view_rect.size.height;
-    
+
     [o_sprefs_win displayIfNeeded];
     [o_sprefs_win setFrame: o_win_rect display:YES animate: YES];
-    
-    [o_new_category_view setFrame: NSMakeRect( 0, 
-                                               [o_sprefs_controls_box frame].size.height, 
-                                               o_view_rect.size.width, 
+
+    [o_new_category_view setFrame: NSMakeRect( 0,
+                                               [o_sprefs_controls_box frame].size.height,
+                                               o_view_rect.size.width,
                                                o_view_rect.size.height )];
     [o_new_category_view setNeedsDisplay: YES];
     [o_new_category_view setAutoresizesSubviews: YES];
     [[o_sprefs_win contentView] addSubview: o_new_category_view];
-    
+
     /* keep our current category for further reference */
     [o_currentlyShownCategoryView release];
     o_currentlyShownCategoryView = o_new_category_view;
@@ -1107,8 +1117,8 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
     {
         [o_audio_norm_stepper setEnabled: [o_audio_norm_ckb state]];
         [o_audio_norm_fld setEnabled: [o_audio_norm_ckb state]];
-    }    
-    
+    }
+
     if( sender == o_audio_last_ckb )
     {
         if( [o_audio_last_ckb state] == NSOnState )
@@ -1143,8 +1153,8 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
         [o_selectFolderPanel setMessage: _NS("Choose the folder to save your video snapshots to.")];
         [o_selectFolderPanel setCanCreateDirectories: YES];
         [o_selectFolderPanel setPrompt: _NS("Choose")];
-        [o_selectFolderPanel beginSheetForDirectory: nil file: nil modalForWindow: o_sprefs_win 
-                                      modalDelegate: self 
+        [o_selectFolderPanel beginSheetForDirectory: nil file: nil modalForWindow: o_sprefs_win
+                                      modalDelegate: self
                                      didEndSelector: @selector(savePanelDidEnd:returnCode:contextInfo:)
                                         contextInfo: o_video_snap_folder_btn];
     }
@@ -1197,10 +1207,6 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
 		[[NSFontManager sharedFontManager] setTarget: self];
 		[[NSFontPanel sharedFontPanel] orderFront:self];
 	}
-	else 
-	{
-		[sender setEnabled: NO];
-	}
 }
 
 - (void)changeFont:(id)sender
@@ -1232,7 +1238,7 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
 {
     if( sender == o_hotkeys_change_btn || sender == o_hotkeys_listbox )
     {
-        [o_hotkeys_change_lbl setStringValue: [NSString stringWithFormat: _NS("Press new keys for\n\"%@\""), 
+        [o_hotkeys_change_lbl setStringValue: [NSString stringWithFormat: _NS("Press new keys for\n\"%@\""),
                                                [o_hotkeyDescriptions objectAtIndex: [o_hotkeys_listbox selectedRow]]]];
         [o_hotkeys_change_keys_lbl setStringValue: [self OSXKeyToString:[[o_hotkeySettings objectAtIndex: [o_hotkeys_listbox selectedRow]] intValue]]];
         [o_hotkeys_change_taken_lbl setStringValue: @""];
@@ -1334,7 +1340,7 @@ static inline void save_module_list( intf_thread_t * p_intf, id object, const ch
         return YES;
     }
 }
-    
+
 @end
 
 /********************
