@@ -2,7 +2,7 @@
  * vlcproc.cpp
  *****************************************************************************
  * Copyright (C) 2003-2009 the VideoLAN team
- * $Id: 6e13a0479ce11c9aa43c368624f2894d841ad37e $
+ * $Id: ad2624acbd80783c2ba0604afc9958982721e785 $
  *
  * Authors: Cyril Deguet     <asmax@via.ecp.fr>
  *          Olivier Teulière <ipkiss@via.ecp.fr>
@@ -31,6 +31,7 @@
 #include <vlc_aout.h>
 #include <vlc_vout.h>
 #include <vlc_playlist.h>
+#include <vlc_url.h>
 
 #include "vlcproc.hpp"
 #include "os_factory.hpp"
@@ -441,9 +442,12 @@ void VlcProc::on_item_current_changed( vlc_object_t* p_obj, vlc_value_t newVal )
     SET_TEXT( m_cVarStreamName, UString( getIntf(), psz_name ) );
     free( psz_name );
 
-    // Update full uri
+    // Update local path (if possible) or full uri
     char *psz_uri = input_item_GetURI( p_item );
-    SET_TEXT( m_cVarStreamURI, UString( getIntf(), psz_uri ) );
+    char *psz_path = make_path( psz_uri );
+    char *psz_save = psz_path ? psz_path : psz_uri;
+    SET_TEXT( m_cVarStreamURI, UString( getIntf(), psz_save ) );
+    free( psz_path );
     free( psz_uri );
 
     // Update playtree
