@@ -2,7 +2,7 @@
  * cmdline.c: command line parsing
  *****************************************************************************
  * Copyright (C) 2001-2007 the VideoLAN team
- * $Id: 264f84ed2f9670e21e734439c44b84aeb67b1ad1 $
+ * $Id: 9befc0e975accde18c700e45eef5f5dbd8744a0c $
  *
  * Authors: Gildas Bazin <gbazin@videolan.org>
  *
@@ -30,59 +30,42 @@
 #include <vlc_keys.h>
 #include <vlc_charset.h>
 
-#ifdef HAVE_GETOPT_LONG
-#   ifdef HAVE_GETOPT_H
-#       include <getopt.h>                                       /* getopt() */
-#   endif
-#else
-#   include "../extras/getopt.h"
-#endif
+#include "vlc_getopt.h"
 
 #include "configuration.h"
 #include "modules/modules.h"
 
 #include <assert.h>
 
-/*****************************************************************************
- * config_LoadCmdLine: parse command line
- *****************************************************************************
+#undef config_LoadCmdLine
+/**
  * Parse command line for configuration options.
+ *
  * Now that the module_bank has been initialized, we can dynamically
  * generate the longopts structure used by getops. We have to do it this way
  * because we don't know (and don't want to know) in advance the configuration
  * options used (ie. exported) by each module.
- *****************************************************************************/
-int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
-                          const char *ppsz_argv[],
-                          bool b_ignore_errors )
+ *
+ * @param p_this object to write command line options as variables to
+ * @param i_argc number of command line arguments
+ * @param ppsz_args commandl ine arguments [IN/OUT]
+ * @param pindex NULL to ignore unknown options,
+ *               otherwise index of the first non-option argument [OUT]
+ * @return 0 on success, -1 on error.
+ */
+int config_LoadCmdLine( vlc_object_t *p_this, int i_argc,
+                        const char *ppsz_argv[], int *pindex )
 {
     int i_cmd, i_index, i_opts, i_shortopts, flag, i_verbose = 0;
     module_t *p_parser;
-    struct option *p_longopts;
+    struct vlc_option *p_longopts;
     const char **argv_copy = NULL;
+#define b_ignore_errors (pindex == NULL)
 
     /* Short options */
     module_config_t *pp_shortopts[256];
     char *psz_shortopts;
 
-#ifdef __APPLE__
-    /* When VLC.app is run by double clicking in Mac OS X, the 2nd arg
-     * is the PSN - process serial number (a unique PID-ish thingie)
-     * still ok for real Darwin & when run from command line */
-    if ( (*pi_argc > 1) && (strncmp( ppsz_argv[ 1 ] , "-psn" , 4 ) == 0) )
-                                        /* for example -psn_0_9306113 */
-    {
-        /* GDMF!... I can't do this or else the MacOSX window server will
-         * not pick up the PSN and not register the app and we crash...
-         * hence the following kludge otherwise we'll get confused w/ argv[1]
-         * being an input file name.
-         * As there won't be any more args to parse, just exit. */
-        assert( *pi_argc == 2 );
-        *pi_argc = 1;
-        return 0;
-    }
-#endif
-
     /* List all modules */
     module_t **list = module_list_get (NULL);
 
@@ -97,14 +80,14 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
          * dealing with boolean to allow for --foo and --no-foo */
         i_opts += p_parser->i_config_items + 2 * p_parser->i_bool_items;
 
-    p_longopts = malloc( sizeof(struct option) * (i_opts + 1) );
+    p_longopts = malloc( sizeof(*p_longopts) * (i_opts + 1) );
     if( p_longopts == NULL )
     {
         module_list_free (list);
         return -1;
     }
 
-    psz_shortopts = malloc( sizeof( char ) * (2 * i_opts + 1) );
+    psz_shortopts = malloc( 2 * i_opts + 1 );
     if( psz_shortopts == NULL )
     {
         free( p_longopts );
@@ -117,7 +100,7 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
      * us, ignoring the arity of the options */
     if( b_ignore_errors )
     {
-        argv_copy = (const char**)malloc( *pi_argc * sizeof(char *) );
+        argv_copy = (const char**)malloc( i_argc * sizeof(char *) );
         if( argv_copy == NULL )
         {
             free( psz_shortopts );
@@ -125,7 +108,7 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
             module_list_free (list);
             return -1;
         }
-        memcpy( argv_copy, ppsz_argv, *pi_argc * sizeof(char *) );
+        memcpy( argv_copy, ppsz_argv, i_argc * sizeof(char *) );
         ppsz_argv = argv_copy;
     }
 
@@ -156,14 +139,7 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
             p_longopts[i_index].name = strdup( p_item->psz_name );
             if( p_longopts[i_index].name == NULL ) continue;
             p_longopts[i_index].has_arg =
-                (p_item->i_type == CONFIG_ITEM_BOOL) ? no_argument : 
-#ifndef __APPLE__
-                                                       required_argument;
-#else
-/* It seems that required_argument is broken on Darwin.
- * Radar ticket #6113829 */
-                                                       optional_argument;
-#endif
+                (p_item->i_type != CONFIG_ITEM_BOOL);
             p_longopts[i_index].flag = &flag;
             p_longopts[i_index].val = 0;
             i_index++;
@@ -178,7 +154,7 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
                 strcat( psz_name, p_item->psz_name );
 
                 p_longopts[i_index].name = psz_name;
-                p_longopts[i_index].has_arg = no_argument;
+                p_longopts[i_index].has_arg = false;
                 p_longopts[i_index].flag = &flag;
                 p_longopts[i_index].val = 1;
                 i_index++;
@@ -189,7 +165,7 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
                 strcat( psz_name, p_item->psz_name );
 
                 p_longopts[i_index].name = psz_name;
-                p_longopts[i_index].has_arg = no_argument;
+                p_longopts[i_index].has_arg = false;
                 p_longopts[i_index].flag = &flag;
                 p_longopts[i_index].val = 1;
                 i_index++;
@@ -201,16 +177,11 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
                 pp_shortopts[(int)p_item->i_short] = p_item;
                 psz_shortopts[i_shortopts] = p_item->i_short;
                 i_shortopts++;
-                if( p_item->i_type != CONFIG_ITEM_BOOL )
+                if( p_item->i_type != CONFIG_ITEM_BOOL
+                 && p_item->i_short != 'v' )
                 {
                     psz_shortopts[i_shortopts] = ':';
                     i_shortopts++;
-
-                    if( p_item->i_short == 'v' )
-                    {
-                        psz_shortopts[i_shortopts] = ':';
-                        i_shortopts++;
-                    }
                 }
             }
         }
@@ -220,22 +191,25 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
     module_list_free( list );
 
     /* Close the longopts and shortopts structures */
-    memset( &p_longopts[i_index], 0, sizeof(struct option) );
+    memset( &p_longopts[i_index], 0, sizeof(*p_longopts) );
     psz_shortopts[i_shortopts] = '\0';
 
+    int ret = -1;
+
     /*
      * Parse the command line options
      */
-    opterr = 0;
-    optind = 0; /* set to 0 to tell GNU getopt to reinitialize */
-    while( ( i_cmd = getopt_long( *pi_argc, (char **)ppsz_argv, psz_shortopts,
-                                  p_longopts, &i_index ) ) != -1 )
+    vlc_getopt_t state;
+    state.optind = 0 ; /* set to 0 to tell GNU getopt to reinitialize */
+    while( ( i_cmd = vlc_getopt_long( i_argc, (char **)ppsz_argv,
+                                      psz_shortopts,
+                                      p_longopts, &i_index, &state ) ) != -1 )
     {
         /* A long option has been recognized */
         if( i_cmd == 0 )
         {
             module_config_t *p_conf;
-            char *psz_name = (char *)p_longopts[i_index].name;
+            const char *psz_name = p_longopts[i_index].name;
 
             /* Check if we deal with a --nofoo or --no-foo long option */
             if( flag ) psz_name += psz_name[2] == '-' ? 3 : 2;
@@ -256,31 +230,17 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
                 if( p_conf->psz_oldname
                  && !strcmp( p_conf->psz_oldname, psz_name) )
                 {
-                    fprintf( stderr,
-                             "%s: option --%s is deprecated. Use --%s instead.\n",
-                             b_ignore_errors ? "Warning" : "Error",
-                             psz_name, p_conf->psz_name );
                     if( !b_ignore_errors )
                     {
-                        /*free */
-                        for( i_index = 0; p_longopts[i_index].name; i_index++ )
-                             free( (char *)p_longopts[i_index].name );
-
-                        free( p_longopts );
-                        free( psz_shortopts );
-                        return -1;
+                        fprintf( stderr, "Error: option --%s is deprecated. "
+                                 "Use --%s instead.\n",
+                                 psz_name, p_conf->psz_name );
+                        goto out;
                     }
 
                     psz_name = p_conf->psz_name;
                 }
-#ifdef __APPLE__
-                if( p_conf->i_type != CONFIG_ITEM_BOOL && !optarg )
-                {
-                    fprintf( stderr, "Warning: missing argument for option --%s\n", p_conf->psz_name );
-                    fprintf( stderr, "Try specifying options as '--optionname=value' instead of '--optionname value'\n" );
-                    continue;
-                }
-#endif
+
                 switch( p_conf->i_type )
                 {
                     case CONFIG_ITEM_STRING:
@@ -291,19 +251,26 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
                     case CONFIG_ITEM_MODULE_LIST:
                     case CONFIG_ITEM_MODULE_LIST_CAT:
                     case CONFIG_ITEM_MODULE_CAT:
-                        config_PutPsz( p_this, psz_name, optarg );
+                        var_Create( p_this, psz_name, VLC_VAR_STRING );
+                        var_SetString( p_this, psz_name, state.optarg );
                         break;
                     case CONFIG_ITEM_INTEGER:
-                        config_PutInt( p_this, psz_name, strtol(optarg, 0, 0));
+                        var_Create( p_this, psz_name, VLC_VAR_INTEGER );
+                        var_SetInteger( p_this, psz_name,
+                                        strtol(state.optarg, NULL, 0));
                         break;
                     case CONFIG_ITEM_FLOAT:
-                        config_PutFloat( p_this, psz_name, us_atof(optarg) );
+                        var_Create( p_this, psz_name, VLC_VAR_FLOAT );
+                        var_SetFloat( p_this, psz_name, us_atof(state.optarg) );
                         break;
                     case CONFIG_ITEM_KEY:
-                        config_PutInt( p_this, psz_name, ConfigStringToKey( optarg ) );
+                        var_Create( p_this, psz_name, VLC_VAR_INTEGER );
+                        var_SetInteger( p_this, psz_name,
+                                        ConfigStringToKey( state.optarg ) );
                         break;
                     case CONFIG_ITEM_BOOL:
-                        config_PutInt( p_this, psz_name, !flag );
+                        var_Create( p_this, psz_name, VLC_VAR_BOOL );
+                        var_SetBool( p_this, psz_name, !flag );
                         break;
                 }
                 continue;
@@ -313,6 +280,7 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
         /* A short option has been recognized */
         if( pp_shortopts[i_cmd] != NULL )
         {
+            const char *name = pp_shortopts[i_cmd]->psz_name;
             switch( pp_shortopts[i_cmd]->i_type )
             {
                 case CONFIG_ITEM_STRING:
@@ -323,42 +291,25 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
                 case CONFIG_ITEM_MODULE_CAT:
                 case CONFIG_ITEM_MODULE_LIST:
                 case CONFIG_ITEM_MODULE_LIST_CAT:
-                    config_PutPsz( p_this, pp_shortopts[i_cmd]->psz_name, optarg );
+                    var_Create( p_this, name, VLC_VAR_STRING );
+                    var_SetString( p_this, name, state.optarg );
                     break;
                 case CONFIG_ITEM_INTEGER:
+                    var_Create( p_this, name, VLC_VAR_INTEGER );
                     if( i_cmd == 'v' )
                     {
-                        if( optarg )
-                        {
-                            if( *optarg == 'v' ) /* eg. -vvv */
-                            {
-                                i_verbose++;
-                                while( *optarg == 'v' )
-                                {
-                                    i_verbose++;
-                                    optarg++;
-                                }
-                            }
-                            else
-                            {
-                                i_verbose += atoi( optarg ); /* eg. -v2 */
-                            }
-                        }
-                        else
-                        {
-                            i_verbose++; /* -v */
-                        }
-                        config_PutInt( p_this, pp_shortopts[i_cmd]->psz_name,
-                                               i_verbose );
+                        i_verbose++; /* -v */
+                        var_SetInteger( p_this, name, i_verbose );
                     }
                     else
                     {
-                        config_PutInt( p_this, pp_shortopts[i_cmd]->psz_name,
-                                               strtol(optarg, 0, 0) );
+                        var_SetInteger( p_this, name,
+                                        strtol(state.optarg, NULL, 0) );
                     }
                     break;
                 case CONFIG_ITEM_BOOL:
-                    config_PutInt( p_this, pp_shortopts[i_cmd]->psz_name, 1 );
+                    var_Create( p_this, name, VLC_VAR_BOOL );
+                    var_SetBool( p_this, name, true );
                     break;
             }
 
@@ -370,31 +321,29 @@ int __config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
         {
             fputs( "vlc: unknown option"
                      " or missing mandatory argument ", stderr );
-            if( optopt )
+            if( state.optopt )
             {
-                fprintf( stderr, "`-%c'\n", optopt );
+                fprintf( stderr, "`-%c'\n", state.optopt );
             }
             else
             {
-                fprintf( stderr, "`%s'\n", ppsz_argv[optind-1] );
+                fprintf( stderr, "`%s'\n", ppsz_argv[state.optind-1] );
             }
             fputs( "Try `vlc --help' for more information.\n", stderr );
-
-            for( i_index = 0; p_longopts[i_index].name; i_index++ )
-                free( (char *)p_longopts[i_index].name );
-            free( p_longopts );
-            free( psz_shortopts );
-            return -1;
+            goto out;
         }
     }
 
+    ret = 0;
+    if( pindex != NULL )
+        *pindex = state.optind;
+out:
     /* Free allocated resources */
     for( i_index = 0; p_longopts[i_index].name; i_index++ )
         free( (char *)p_longopts[i_index].name );
     free( p_longopts );
     free( psz_shortopts );
     free( argv_copy );
-
-    return 0;
+    return ret;
 }
 
