@@ -2,7 +2,7 @@
  * demux.c
  *****************************************************************************
  * Copyright (C) 1999-2004 the VideoLAN team
- * $Id: a6fe6d0169d354408f19aaf6176b84f75b072f4b $
+ * $Id: 981799ff2d7da30693b11f4065824f186f64c405 $
  *
  * Author: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -37,7 +37,7 @@ static bool SkipAPETag( demux_t *p_demux );
  * demux_New:
  *  if s is NULL then load a access_demux
  *****************************************************************************/
-demux_t *__demux_New( vlc_object_t *p_obj,
+demux_t *__demux_New( vlc_object_t *p_obj, input_thread_t *p_parent_input,
                        const char *psz_access, const char *psz_demux,
                        const char *psz_path,
                        stream_t *s, es_out_t *out, bool b_quick )
@@ -49,6 +49,8 @@ demux_t *__demux_New( vlc_object_t *p_obj,
 
     if( p_demux == NULL ) return NULL;
 
+    p_demux->p_input = p_parent_input;
+
     /* Parse URL */
     p_demux->psz_access = strdup( psz_access );
     p_demux->psz_demux  = strdup( psz_demux );
@@ -99,7 +101,8 @@ demux_t *__demux_New( vlc_object_t *p_obj,
             { "flac", "flac" },
             { "dv",   "dv" },
             { "drc",  "dirac" },
-            { "m3u",  "playlist" },
+            { "m3u",  "m3u" },
+            { "m3u8", "m3u8" },
             { "mkv",  "mkv" }, { "mka",  "mkv" }, { "mks",  "mkv" },
             { "mp4",  "mp4" }, { "m4a",  "mp4" }, { "mov",  "mp4" }, { "moov", "mp4" },
             { "nsv",  "nsv" },
@@ -164,20 +167,17 @@ demux_t *__demux_New( vlc_object_t *p_obj,
 
         p_demux->p_module =
             module_need( p_demux, "demux", psz_module,
-                         !strcmp( psz_module, p_demux->psz_demux ) ?
-                         true : false );
+                         !strcmp( psz_module, p_demux->psz_demux ) );
     }
     else
     {
         p_demux->p_module =
             module_need( p_demux, "access_demux", psz_module,
-                         !strcmp( psz_module, p_demux->psz_access ) ?
-                         true : false );
+                         !strcmp( psz_module, p_demux->psz_access ) );
     }
 
     if( p_demux->p_module == NULL )
     {
-        vlc_object_detach( p_demux );
         free( p_demux->psz_path );
         free( p_demux->psz_demux );
         free( p_demux->psz_access );
@@ -194,7 +194,6 @@ demux_t *__demux_New( vlc_object_t *p_obj,
 void demux_Delete( demux_t *p_demux )
 {
     module_unneed( p_demux, p_demux->p_module );
-    vlc_object_detach( p_demux );
 
     free( p_demux->psz_path );
     free( p_demux->psz_demux );
@@ -203,6 +202,15 @@ void demux_Delete( demux_t *p_demux )
     vlc_object_release( p_demux );
 }
 
+/*****************************************************************************
+ * demux_GetParentInput:
+ *****************************************************************************/
+input_thread_t * demux_GetParentInput( demux_t *p_demux )
+{
+    return p_demux->p_input ? vlc_object_hold((vlc_object_t*)p_demux->p_input) : NULL;
+}
+
+
 /*****************************************************************************
  * demux_vaControlHelper:
  *****************************************************************************/
@@ -300,8 +308,9 @@ int demux_vaControlHelper( stream_t *s,
  ****************************************************************************/
 decoder_t *demux_PacketizerNew( demux_t *p_demux, es_format_t *p_fmt, const char *psz_msg )
 {
-    decoder_t *p_packetizer = vlc_object_create( p_demux, VLC_OBJECT_PACKETIZER );
-
+    decoder_t *p_packetizer;
+    p_packetizer = vlc_custom_create( p_demux, sizeof( *p_packetizer ),
+                                      VLC_OBJECT_GENERIC, "demux packetizer" );
     if( !p_packetizer )
     {
         es_format_Clean( p_fmt );
@@ -317,6 +326,7 @@ decoder_t *demux_PacketizerNew( demux_t *p_demux, es_format_t *p_fmt, const char
     p_packetizer->fmt_in = *p_fmt;
     es_format_Init( &p_packetizer->fmt_out, UNKNOWN_ES, 0 );
 
+    vlc_object_attach( p_packetizer, p_demux );
     p_packetizer->p_module = module_need( p_packetizer, "packetizer", NULL, false );
     if( !p_packetizer->p_module )
     {
@@ -328,6 +338,7 @@ decoder_t *demux_PacketizerNew( demux_t *p_demux, es_format_t *p_fmt, const char
 
     return p_packetizer;
 }
+
 void demux_PacketizerDestroy( decoder_t *p_packetizer )
 {
     if( p_packetizer->p_module )
