@@ -2,7 +2,7 @@
  * item.c: input_item management
  *****************************************************************************
  * Copyright (C) 1998-2004 the VideoLAN team
- * $Id: 7349d9e05bce853ce87f0046373fc8d078d8f41f $
+ * $Id: 0d374afc22f77a0eff14fc4bcf3d80003573da32 $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *
@@ -30,10 +30,12 @@
 #include <vlc_url.h>
 #include "vlc_playlist.h"
 #include "vlc_interface.h"
+#include <vlc_charset.h>
 
 #include "item.h"
+#include "info.h"
 
-static void GuessType( input_item_t *p_item );
+static int GuessType( const input_item_t *p_item );
 
 /** Stuff moved out of vlc_input.h -- FIXME: should probably not be inline
  * anyway. */
@@ -47,6 +49,7 @@ static inline void input_item_Init( vlc_object_t *p_o, input_item_t *p_i )
     TAB_INIT( p_i->i_options, p_i->ppsz_options );
     p_i->optflagv = NULL, p_i->optflagc = 0;
     TAB_INIT( p_i->i_categories, p_i->pp_categories );
+    TAB_INIT( p_i->i_epg, p_i->pp_epg );
 
     p_i->i_type = ITEM_TYPE_UNKNOWN;
     p_i->b_fixed_name = true;
@@ -59,6 +62,7 @@ static inline void input_item_Init( vlc_object_t *p_o, input_item_t *p_i )
     vlc_event_manager_init( p_em, p_i, p_o );
     vlc_event_manager_register_event_type( p_em, vlc_InputItemMetaChanged );
     vlc_event_manager_register_event_type( p_em, vlc_InputItemSubItemAdded );
+    vlc_event_manager_register_event_type( p_em, vlc_InputItemSubItemTreeAdded );
     vlc_event_manager_register_event_type( p_em, vlc_InputItemDurationChanged );
     vlc_event_manager_register_event_type( p_em, vlc_InputItemPreparsedChanged );
     vlc_event_manager_register_event_type( p_em, vlc_InputItemNameChanged );
@@ -95,24 +99,12 @@ static inline void input_item_Clean( input_item_t *p_i )
     }
     TAB_CLEAN( p_i->i_es, p_i->es );
 
+    for( i = 0; i < p_i->i_epg; i++ )
+        vlc_epg_Delete( p_i->pp_epg[i] );
+    TAB_CLEAN( p_i->i_epg, p_i->pp_epg );
+
     for( i = 0; i < p_i->i_categories; i++ )
-    {
-        info_category_t *p_category = p_i->pp_categories[i];
-        int j;
-
-        for( j = 0; j < p_category->i_infos; j++ )
-        {
-            struct info_t *p_info = p_category->pp_infos[j];
-
-            free( p_info->psz_name);
-            free( p_info->psz_value );
-            free( p_info );
-        }
-        TAB_CLEAN( p_category->i_infos, p_category->pp_infos );
-
-        free( p_category->psz_name );
-        free( p_category );
-    }
+        info_category_Delete( p_i->pp_categories[i] );
     TAB_CLEAN( p_i->i_categories, p_i->pp_categories );
 
     vlc_mutex_destroy( &p_i->lock );
@@ -146,14 +138,15 @@ void input_item_SetPreparsed( input_item_t *p_i, bool b_preparsed )
     if( !p_i->p_meta )
         p_i->p_meta = vlc_meta_New();
 
-    int i_new_status;
+    int status = vlc_meta_GetStatus(p_i->p_meta);
+    int new_status;
     if( b_preparsed )
-        i_new_status = p_i->p_meta->i_status | ITEM_PREPARSED;
+        new_status = status | ITEM_PREPARSED;
     else
-        i_new_status = p_i->p_meta->i_status & ~ITEM_PREPARSED;
-    if( p_i->p_meta->i_status != i_new_status )
+        new_status = status & ~ITEM_PREPARSED;
+    if( status != new_status )
     {
-        p_i->p_meta->i_status = i_new_status;
+        vlc_meta_SetStatus(p_i->p_meta, new_status);
         b_send_event = true;
     }
 
@@ -163,10 +156,11 @@ void input_item_SetPreparsed( input_item_t *p_i, bool b_preparsed )
     {
         vlc_event_t event;
         event.type = vlc_InputItemPreparsedChanged;
-        event.u.input_item_preparsed_changed.new_status = i_new_status;
+        event.u.input_item_preparsed_changed.new_status = new_status;
         vlc_event_send( &p_i->event_manager, &event );
     }
 }
+
 void input_item_SetArtNotFound( input_item_t *p_i, bool b_not_found )
 {
     vlc_mutex_lock( &p_i->lock );
@@ -174,13 +168,18 @@ void input_item_SetArtNotFound( input_item_t *p_i, bool b_not_found )
     if( !p_i->p_meta )
         p_i->p_meta = vlc_meta_New();
 
+    int status = vlc_meta_GetStatus(p_i->p_meta);
+
     if( b_not_found )
-        p_i->p_meta->i_status |= ITEM_ART_NOTFOUND;
+        status |= ITEM_ART_NOTFOUND;
     else
-        p_i->p_meta->i_status &= ~ITEM_ART_NOTFOUND;
+        status &= ~ITEM_ART_NOTFOUND;
+
+    vlc_meta_SetStatus(p_i->p_meta, status);
 
     vlc_mutex_unlock( &p_i->lock );
 }
+
 void input_item_SetArtFetched( input_item_t *p_i, bool b_art_fetched )
 {
     vlc_mutex_lock( &p_i->lock );
@@ -188,10 +187,14 @@ void input_item_SetArtFetched( input_item_t *p_i, bool b_art_fetched )
     if( !p_i->p_meta )
         p_i->p_meta = vlc_meta_New();
 
+    int status = vlc_meta_GetStatus(p_i->p_meta);
+
     if( b_art_fetched )
-        p_i->p_meta->i_status |= ITEM_ART_FETCHED;
+        status |= ITEM_ART_FETCHED;
     else
-        p_i->p_meta->i_status &= ~ITEM_ART_FETCHED;
+        status &= ~ITEM_ART_FETCHED;
+
+    vlc_meta_SetStatus(p_i->p_meta, status);
 
     vlc_mutex_unlock( &p_i->lock );
 }
@@ -212,8 +215,8 @@ void input_item_SetMeta( input_item_t *p_i, vlc_meta_type_t meta_type, const cha
     vlc_event_send( &p_i->event_manager, &event );
 }
 
-/* FIXME GRRRRRRRRRR args should be in the reverse order to be 
- * consistant with (nearly?) all or copy funcs */
+/* FIXME GRRRRRRRRRR args should be in the reverse order to be
+ * consistent with (nearly?) all or copy funcs */
 void input_item_CopyOptions( input_item_t *p_parent,
                              input_item_t *p_child )
 {
@@ -232,24 +235,28 @@ void input_item_CopyOptions( input_item_t *p_parent,
     vlc_mutex_unlock( &p_parent->lock );
 }
 
+static void post_subitems( input_item_node_t *p_node )
+{
+    for( int i = 0; i < p_node->i_children; i++ )
+    {
+        vlc_event_t event;
+        event.type = vlc_InputItemSubItemAdded;
+        event.u.input_item_subitem_added.p_new_child = p_node->pp_children[i]->p_item;
+        vlc_event_send( &p_node->p_item->event_manager, &event );
+
+        post_subitems( p_node->pp_children[i] );
+    }
+}
+
 /* This won't hold the item, but can tell to interested third parties
  * Like the playlist, that there is a new sub item. With this design
  * It is not the input item's responsability to keep all the ref of
  * the input item children. */
-void input_item_AddSubItem( input_item_t *p_parent, input_item_t *p_child )
+void input_item_PostSubItem( input_item_t *p_parent, input_item_t *p_child )
 {
-    vlc_mutex_lock( &p_parent->lock );
-
-    p_parent->i_type = ITEM_TYPE_PLAYLIST;
-
-    vlc_mutex_unlock( &p_parent->lock );
-
-    /* Notify interested third parties */
-    vlc_event_t event;
-
-    event.type = vlc_InputItemSubItemAdded;
-    event.u.input_item_subitem_added.p_new_child = p_child;
-    vlc_event_send( &p_parent->event_manager, &event );
+    input_item_node_t *p_node = input_item_node_Create( p_parent );
+    input_item_node_AppendItem( p_node, p_child );
+    input_item_node_PostAndDelete( p_node );
 }
 
 bool input_item_HasErrorWhenReading( input_item_t *p_item )
@@ -350,37 +357,46 @@ char *input_item_GetURI( input_item_t *p_i )
     vlc_mutex_unlock( &p_i->lock );
     return psz_s;
 }
+
 void input_item_SetURI( input_item_t *p_i, const char *psz_uri )
 {
+    assert( psz_uri );
+#ifndef NDEBUG
+    if( !strstr( psz_uri, "://" )
+     || strchr( psz_uri, ' ' ) || strchr( psz_uri, '"' ) )
+        fprintf( stderr, "Warning: %s(\"%s\"): file path instead of URL.\n",
+                 __func__, psz_uri );
+#endif
     vlc_mutex_lock( &p_i->lock );
-
     free( p_i->psz_uri );
     p_i->psz_uri = strdup( psz_uri );
 
-    GuessType( p_i );
+    p_i->i_type = GuessType( p_i );
 
-    if( !p_i->psz_name && p_i->i_type == ITEM_TYPE_FILE )
+    if( p_i->psz_name )
+        ;
+    else
+    if( p_i->i_type == ITEM_TYPE_FILE || p_i->i_type == ITEM_TYPE_DIRECTORY )
     {
-        const char *psz_filename;
-        bool b_path = !strstr( p_i->psz_uri, "://" );
+        const char *psz_filename = strrchr( p_i->psz_uri, '/' );
 
-        psz_filename = strrchr( p_i->psz_uri, b_path ? DIR_SEP_CHAR : '/' );
-
-        if( psz_filename && ( *psz_filename == (b_path ? DIR_SEP_CHAR : '/') ) )
+        if( psz_filename && *psz_filename == '/' )
             psz_filename++;
         if( psz_filename && *psz_filename )
             p_i->psz_name = strdup( psz_filename );
 
         /* Make the name more readable */
-        if( !b_path && p_i->psz_name )
+        if( p_i->psz_name )
+        {
             decode_URI( p_i->psz_name );
+            EnsureUTF8( p_i->psz_name );
+        }
     }
-
-    /* The name is NULL: fill it with everything except login and password */
-    if( !p_i->psz_name )
-    {
+    else
+    {   /* Strip login and password from title */
         int r;
         vlc_url_t url;
+
         vlc_UrlParse( &url, psz_uri, 0 );
         if( url.psz_protocol )
         {
@@ -446,7 +462,7 @@ void input_item_SetDuration( input_item_t *p_i, mtime_t i_duration )
 bool input_item_IsPreparsed( input_item_t *p_item )
 {
     vlc_mutex_lock( &p_item->lock );
-    bool b_preparsed = p_item->p_meta ? ( p_item->p_meta->i_status & ITEM_PREPARSED ) != 0 : false;
+    bool b_preparsed = p_item->p_meta ? ( vlc_meta_GetStatus(p_item->p_meta) & ITEM_PREPARSED ) != 0 : false;
     vlc_mutex_unlock( &p_item->lock );
 
     return b_preparsed;
@@ -455,7 +471,7 @@ bool input_item_IsPreparsed( input_item_t *p_item )
 bool input_item_IsArtFetched( input_item_t *p_item )
 {
     vlc_mutex_lock( &p_item->lock );
-    bool b_fetched = p_item->p_meta ? ( p_item->p_meta->i_status & ITEM_ART_FETCHED ) != 0 : false;
+    bool b_fetched = p_item->p_meta ? ( vlc_meta_GetStatus(p_item->p_meta) & ITEM_ART_FETCHED ) != 0 : false;
     vlc_mutex_unlock( &p_item->lock );
 
     return b_fetched;
@@ -501,6 +517,24 @@ out:
     return err;
 }
 
+static info_category_t *InputItemFindCat( input_item_t *p_item,
+                                          int *pi_index, const char *psz_cat )
+{
+    vlc_assert_locked( &p_item->lock );
+    for( int i = 0; i < p_item->i_categories && psz_cat; i++ )
+    {
+        info_category_t *p_cat = p_item->pp_categories[i];
+
+        if( !strcmp( p_cat->psz_name, psz_cat ) )
+        {
+            if( pi_index )
+                *pi_index = i;
+            return p_cat;
+        }
+    }
+    return NULL;
+}
+
 /**
  * Get a info item from a given category in a given input item.
  *
@@ -517,21 +551,15 @@ char *input_item_GetInfo( input_item_t *p_i,
 {
     vlc_mutex_lock( &p_i->lock );
 
-    for( int i = 0; i< p_i->i_categories; i++ )
+    const info_category_t *p_cat = InputItemFindCat( p_i, NULL, psz_cat );
+    if( p_cat )
     {
-        const info_category_t *p_cat = p_i->pp_categories[i];
-
-        if( !psz_cat || strcmp( p_cat->psz_name, psz_cat ) )
-            continue;
-
-        for( int j = 0; j < p_cat->i_infos; j++ )
+        info_t *p_info = info_category_FindInfo( p_cat, NULL, psz_name );
+        if( p_info && p_info->psz_value )
         {
-            if( !strcmp( p_cat->pp_infos[j]->psz_name, psz_name ) )
-            {
-                char *psz_ret = strdup( p_cat->pp_infos[j]->psz_value );
-                vlc_mutex_unlock( &p_i->lock );
-                return psz_ret;
-            }
+            char *psz_ret = strdup( p_info->psz_value );
+            vlc_mutex_unlock( &p_i->lock );
+            return psz_ret;
         }
     }
     vlc_mutex_unlock( &p_i->lock );
@@ -543,58 +571,21 @@ static int InputItemVaAddInfo( input_item_t *p_i,
                                const char *psz_name,
                                const char *psz_format, va_list args )
 {
-    int i;
-    info_t *p_info = NULL;
-    info_category_t *p_cat = NULL ;
-
     vlc_assert_locked( &p_i->lock );
 
-    for( i = 0 ; i < p_i->i_categories ; i ++ )
-    {
-        if( !strcmp( p_i->pp_categories[i]->psz_name, psz_cat ) )
-        {
-            p_cat = p_i->pp_categories[i];
-            break;
-        }
-    }
+    info_category_t *p_cat = InputItemFindCat( p_i, NULL, psz_cat );
     if( !p_cat )
     {
-        if( !(p_cat = malloc( sizeof(*p_cat) )) )
+        p_cat = info_category_New( psz_cat );
+        if( !p_cat )
             return VLC_ENOMEM;
-
-        p_cat->psz_name = strdup( psz_cat );
-        p_cat->i_infos = 0;
-        p_cat->pp_infos = 0;
         INSERT_ELEM( p_i->pp_categories, p_i->i_categories, p_i->i_categories,
                      p_cat );
     }
-
-    for( i = 0; i< p_cat->i_infos; i++ )
-    {
-        if( !strcmp( p_cat->pp_infos[i]->psz_name, psz_name ) )
-        {
-            p_info = p_cat->pp_infos[i];
-            break;
-        }
-    }
-
-    if( !p_info )
-    {
-        if( ( p_info = malloc( sizeof( *p_info ) ) ) == NULL )
-            return VLC_ENOMEM;
-
-        INSERT_ELEM( p_cat->pp_infos, p_cat->i_infos, p_cat->i_infos, p_info );
-        p_info->psz_name = strdup( psz_name );
-    }
-    else
-    {
-        free( p_info->psz_value );
-    }
-
-    if( vasprintf( &p_info->psz_value, psz_format, args ) == -1 )
-        p_info->psz_value = NULL;
-
-    return p_info->psz_value ? VLC_SUCCESS : VLC_ENOMEM;
+    info_t *p_info = info_category_VaAddInfo( p_cat, psz_name, psz_format, args );
+    if( !p_info || !p_info->psz_value )
+        return VLC_EGENERIC;
+    return VLC_SUCCESS;
 }
 
 static int InputItemAddInfo( input_item_t *p_i,
@@ -641,21 +632,10 @@ int input_item_DelInfo( input_item_t *p_i,
                         const char *psz_cat,
                         const char *psz_name )
 {
-    info_category_t *p_cat = NULL;
-    int i_cat;
-    int i;
-
     vlc_mutex_lock( &p_i->lock );
-    for( i_cat = 0; i_cat < p_i->i_categories; i_cat++ )
-    {
-        if( !strcmp( p_i->pp_categories[i_cat]->psz_name,
-                     psz_cat ) )
-        {
-            p_cat = p_i->pp_categories[i_cat];
-            break;
-        }
-    }
-    if( p_cat == NULL )
+    int i_cat;
+    info_category_t *p_cat = InputItemFindCat( p_i, &i_cat, psz_cat );
+    if( !p_cat )
     {
         vlc_mutex_unlock( &p_i->lock );
         return VLC_EGENERIC;
@@ -664,18 +644,8 @@ int input_item_DelInfo( input_item_t *p_i,
     if( psz_name )
     {
         /* Remove a specific info */
-        for( i = 0; i < p_cat->i_infos; i++ )
-        {
-            if( !strcmp( p_cat->pp_infos[i]->psz_name, psz_name ) )
-            {
-                free( p_cat->pp_infos[i]->psz_name );
-                free( p_cat->pp_infos[i]->psz_value );
-                free( p_cat->pp_infos[i] );
-                REMOVE_ELEM( p_cat->pp_infos, p_cat->i_infos, i );
-                break;
-            }
-        }
-        if( i >= p_cat->i_infos )
+        int i_ret = info_category_DeleteInfo( p_cat, psz_name );
+        if( i_ret )
         {
             vlc_mutex_unlock( &p_i->lock );
             return VLC_EGENERIC;
@@ -684,19 +654,9 @@ int input_item_DelInfo( input_item_t *p_i,
     else
     {
         /* Remove the complete categorie */
-        for( i = 0; i < p_cat->i_infos; i++ )
-        {
-            free( p_cat->pp_infos[i]->psz_name );
-            free( p_cat->pp_infos[i]->psz_value );
-            free( p_cat->pp_infos[i] );
-        }
-        free( p_cat->pp_infos );
+        info_category_Delete( p_cat );
         REMOVE_ELEM( p_i->pp_categories, p_i->i_categories, i_cat );
     }
-
-    // Free the category
-    free( p_cat->psz_name );
-    free( p_cat );
     vlc_mutex_unlock( &p_i->lock );
 
 
@@ -706,10 +666,92 @@ int input_item_DelInfo( input_item_t *p_i,
 
     return VLC_SUCCESS;
 }
-
-void input_item_SetEpg( input_item_t *p_item,
-                        const char *psz_epg, const vlc_epg_t *p_epg )
+void input_item_ReplaceInfos( input_item_t *p_item, info_category_t *p_cat )
 {
+    vlc_mutex_lock( &p_item->lock );
+    int i_cat;
+    info_category_t *p_old = InputItemFindCat( p_item, &i_cat, p_cat->psz_name );
+    if( p_old )
+    {
+        info_category_Delete( p_old );
+        p_item->pp_categories[i_cat] = p_cat;
+    }
+    else
+    {
+        INSERT_ELEM( p_item->pp_categories, p_item->i_categories, p_item->i_categories,
+                     p_cat );
+    }
+    vlc_mutex_unlock( &p_item->lock );
+
+
+    vlc_event_t event;
+    event.type = vlc_InputItemInfoChanged;
+    vlc_event_send( &p_item->event_manager, &event );
+}
+void input_item_MergeInfos( input_item_t *p_item, info_category_t *p_cat )
+{
+    vlc_mutex_lock( &p_item->lock );
+    info_category_t *p_old = InputItemFindCat( p_item, NULL, p_cat->psz_name );
+    if( p_old )
+    {
+        for( int i = 0; i < p_cat->i_infos; i++ )
+            info_category_ReplaceInfo( p_old, p_cat->pp_infos[i] );
+        TAB_CLEAN( p_cat->i_infos, p_cat->pp_infos );
+        info_category_Delete( p_cat );
+    }
+    else
+    {
+        INSERT_ELEM( p_item->pp_categories, p_item->i_categories, p_item->i_categories,
+                     p_cat );
+    }
+    vlc_mutex_unlock( &p_item->lock );
+
+
+    vlc_event_t event;
+    event.type = vlc_InputItemInfoChanged;
+    vlc_event_send( &p_item->event_manager, &event );
+}
+
+#define EPG_DEBUG
+void input_item_SetEpg( input_item_t *p_item, const vlc_epg_t *p_update )
+{
+    vlc_mutex_lock( &p_item->lock );
+
+    /* */
+    vlc_epg_t *p_epg = NULL;
+    for( int i = 0; i < p_item->i_epg; i++ )
+    {
+        vlc_epg_t *p_tmp = p_item->pp_epg[i];
+
+        if( (p_tmp->psz_name == NULL) != (p_update->psz_name == NULL) )
+            continue;
+        if( p_tmp->psz_name && p_update->psz_name && strcmp(p_tmp->psz_name, p_update->psz_name) )
+            continue;
+
+        p_epg = p_tmp;
+        break;
+    }
+
+    /* */
+    if( !p_epg )
+    {
+        p_epg = vlc_epg_New( p_update->psz_name );
+        if( p_epg )
+            TAB_APPEND( p_item->i_epg, p_item->pp_epg, p_epg );
+    }
+    if( p_epg )
+        vlc_epg_Merge( p_epg, p_update );
+
+    vlc_mutex_unlock( &p_item->lock );
+
+    if( !p_epg )
+        return;
+
+#ifdef EPG_DEBUG
+    char *psz_epg;
+    if( asprintf( &psz_epg, "EPG %s", p_epg->psz_name ? p_epg->psz_name : "unknown" ) < 0 )
+        goto signal;
+
     input_item_DelInfo( p_item, psz_epg, NULL );
 
     vlc_mutex_lock( &p_item->lock );
@@ -737,23 +779,56 @@ void input_item_SetEpg( input_item_t *p_item,
                               p_evt->i_duration/60/60, (p_evt->i_duration/60)%60 );
     }
     vlc_mutex_unlock( &p_item->lock );
+    free( psz_epg );
+signal:
+#endif
 
     if( p_epg->i_event > 0 )
     {
-        vlc_event_t event;
-
-        event.type = vlc_InputItemInfoChanged;
+        vlc_event_t event = { .type = vlc_InputItemInfoChanged, };
         vlc_event_send( &p_item->event_manager, &event );
     }
 }
 
+void input_item_SetEpgOffline( input_item_t *p_item )
+{
+    vlc_mutex_lock( &p_item->lock );
+    for( int i = 0; i < p_item->i_epg; i++ )
+        vlc_epg_SetCurrent( p_item->pp_epg[i], -1 );
+    vlc_mutex_unlock( &p_item->lock );
 
-input_item_t *__input_item_NewExt( vlc_object_t *p_obj, const char *psz_uri,
-                                  const char *psz_name,
-                                  int i_options,
-                                  const char *const *ppsz_options,
-                                  unsigned i_option_flags,
-                                  mtime_t i_duration )
+#ifdef EPG_DEBUG
+    vlc_mutex_lock( &p_item->lock );
+    const int i_epg_info = p_item->i_epg;
+    char *ppsz_epg_info[i_epg_info];
+    for( int i = 0; i < p_item->i_epg; i++ )
+    {
+        const vlc_epg_t *p_epg = p_item->pp_epg[i];
+        if( asprintf( &ppsz_epg_info[i], "EPG %s", p_epg->psz_name ? p_epg->psz_name : "unknown" ) < 0 )
+            ppsz_epg_info[i] = NULL;
+    }
+    vlc_mutex_unlock( &p_item->lock );
+
+    for( int i = 0; i < i_epg_info; i++ )
+    {
+        if( !ppsz_epg_info[i] )
+            continue;
+        input_item_DelInfo( p_item, ppsz_epg_info[i], NULL );
+        free( ppsz_epg_info[i] );
+    }
+#endif
+
+    vlc_event_t event = { .type = vlc_InputItemInfoChanged, };
+    vlc_event_send( &p_item->event_manager, &event );
+}
+
+#undef input_item_NewExt
+input_item_t *input_item_NewExt( vlc_object_t *p_obj, const char *psz_uri,
+                                 const char *psz_name,
+                                 int i_options,
+                                 const char *const *ppsz_options,
+                                 unsigned i_option_flags,
+                                 mtime_t i_duration )
 {
     return input_item_NewWithType( p_obj, psz_uri, psz_name,
                                   i_options, ppsz_options, i_option_flags,
@@ -786,7 +861,6 @@ input_item_t *input_item_NewWithType( vlc_object_t *p_obj, const char *psz_uri,
     p_input->b_fixed_name = false;
 
     p_input->i_type = i_type;
-    p_input->b_prefers_tree = false;
 
     if( psz_uri )
         input_item_SetURI( p_input, psz_uri );
@@ -804,45 +878,175 @@ input_item_t *input_item_NewWithType( vlc_object_t *p_obj, const char *psz_uri,
     return p_input;
 }
 
-/* Guess the type of the item using the beginning of the mrl */
-static void GuessType( input_item_t *p_item)
+input_item_t *input_item_Copy( vlc_object_t *p_obj, input_item_t *p_input )
 {
-    int i;
-    static struct { const char *psz_search; int i_type; }  types_array[] =
-    {
-        { "http", ITEM_TYPE_NET },
-        { "dvd", ITEM_TYPE_DISC },
-        { "cdda", ITEM_TYPE_CDDA },
-        { "mms", ITEM_TYPE_NET },
-        { "rtsp", ITEM_TYPE_NET },
-        { "udp", ITEM_TYPE_NET },
-        { "rtp", ITEM_TYPE_NET },
-        { "vcd", ITEM_TYPE_DISC },
-        { "v4l", ITEM_TYPE_CARD },
-        { "dshow", ITEM_TYPE_CARD },
-        { "pvr", ITEM_TYPE_CARD },
-        { "dvb", ITEM_TYPE_CARD },
-        { "qpsk", ITEM_TYPE_CARD },
-        { "sdp", ITEM_TYPE_NET },
-        { "ftp", ITEM_TYPE_NET },
-        { "smb", ITEM_TYPE_NET },
-        { NULL, 0 }
-    };
+    vlc_mutex_lock( &p_input->lock );
 
-    if( !p_item->psz_uri || !strstr( p_item->psz_uri, "://" ) )
-    {
-        p_item->i_type = ITEM_TYPE_FILE;
-        return;
-    }
+    input_item_t *p_new_input =
+        input_item_NewWithType( p_obj,
+                                p_input->psz_uri, p_input->psz_name,
+                                0, NULL, 0, p_input->i_duration,
+                                p_input->i_type );
 
-    for( i = 0; types_array[i].psz_search != NULL; i++ )
+    if( p_new_input )
     {
-        if( !strncmp( p_item->psz_uri, types_array[i].psz_search,
-                      strlen( types_array[i].psz_search ) ) )
+        for( int i = 0 ; i< p_input->i_options; i++ )
         {
-            p_item->i_type = types_array[i].i_type;
-            return;
+            input_item_AddOption( p_new_input,
+                                  p_input->ppsz_options[i],
+                                  p_input->optflagv[i] );
         }
     }
-    p_item->i_type = ITEM_TYPE_FILE;
+
+    vlc_mutex_unlock( &p_input->lock );
+
+    return p_new_input;
+}
+
+struct item_type_entry
+{
+    const char psz_scheme[7];
+    uint8_t    i_type;
+};
+
+static int typecmp( const void *key, const void *entry )
+{
+    const struct item_type_entry *type = entry;
+    const char *uri = key, *scheme = type->psz_scheme;
+
+    return strncmp( uri, scheme, strlen( scheme ) );
+}
+
+/* Guess the type of the item using the beginning of the mrl */
+static int GuessType( const input_item_t *p_item )
+{
+    static const struct item_type_entry tab[] =
+    {   /* /!\ Alphabetical order /!\ */
+        /* Short match work, not just exact match */
+        { "alsa",   ITEM_TYPE_CARD },
+        { "atsc",   ITEM_TYPE_CARD },
+        { "bd",     ITEM_TYPE_DISC },
+        { "cable",  ITEM_TYPE_CARD },
+        { "cdda",   ITEM_TYPE_CDDA },
+        { "dc1394", ITEM_TYPE_CARD },
+        { "dccp",   ITEM_TYPE_NET },
+        { "dir",    ITEM_TYPE_DIRECTORY },
+        { "dshow",  ITEM_TYPE_CARD },
+        { "dv",     ITEM_TYPE_CARD },
+        { "dvb",    ITEM_TYPE_CARD },
+        { "dvd",    ITEM_TYPE_DISC },
+        { "ftp",    ITEM_TYPE_NET },
+        { "http",   ITEM_TYPE_NET },
+        { "icyx",   ITEM_TYPE_NET },
+        { "itpc",   ITEM_TYPE_NET },
+        { "jack",   ITEM_TYPE_CARD },
+        { "live",   ITEM_TYPE_NET }, /* livedotcom */
+        { "mms",    ITEM_TYPE_NET },
+        { "mtp",    ITEM_TYPE_DISC },
+        { "ofdm",   ITEM_TYPE_CARD },
+        { "oss",    ITEM_TYPE_CARD },
+        { "pnm",    ITEM_TYPE_NET },
+        { "pvr",    ITEM_TYPE_CARD },
+        { "qam",    ITEM_TYPE_CARD },
+        { "qpsk",   ITEM_TYPE_CARD },
+        { "qtcapt", ITEM_TYPE_CARD }, /* qtcapture */
+        { "raw139", ITEM_TYPE_CARD }, /* raw1394 */
+        { "rt",     ITEM_TYPE_NET }, /* rtp, rtsp, rtmp */
+        { "satell", ITEM_TYPE_CARD }, /* sattelite */
+        { "screen", ITEM_TYPE_CARD },
+        { "sdp",    ITEM_TYPE_NET },
+        { "smb",    ITEM_TYPE_NET },
+        { "svcd",   ITEM_TYPE_DISC },
+        { "tcp",    ITEM_TYPE_NET },
+        { "terres", ITEM_TYPE_CARD }, /* terrestrial */
+        { "udp",    ITEM_TYPE_NET },  /* udplite too */
+        { "unsv",   ITEM_TYPE_NET },
+        { "usdigi", ITEM_TYPE_CARD }, /* usdigital */
+        { "v4l",    ITEM_TYPE_CARD },
+        { "vcd",    ITEM_TYPE_DISC },
+        { "window", ITEM_TYPE_CARD },
+    };
+    const struct item_type_entry *e;
+
+    if( !strstr( p_item->psz_uri, "://" ) )
+        return ITEM_TYPE_FILE;
+
+    e = bsearch( p_item->psz_uri, tab, sizeof( tab ) / sizeof( tab[0] ),
+                 sizeof( tab[0] ), typecmp );
+    return e ? e->i_type : ITEM_TYPE_FILE;
+}
+
+input_item_node_t *input_item_node_Create( input_item_t *p_input )
+{
+    input_item_node_t* p_node = malloc( sizeof( input_item_node_t ) );
+    if( !p_node )
+        return NULL;
+
+    assert( p_input );
+
+    p_node->p_item = p_input;
+    vlc_gc_incref( p_input );
+
+    p_node->p_parent = NULL;
+    p_node->i_children = 0;
+    p_node->pp_children = NULL;
+
+    return p_node;
+}
+
+static void RecursiveNodeDelete( input_item_node_t *p_node )
+{
+  for( int i = 0; i < p_node->i_children; i++ )
+      RecursiveNodeDelete( p_node->pp_children[i] );
+
+  vlc_gc_decref( p_node->p_item );
+  free( p_node->pp_children );
+  free( p_node );
+}
+
+void input_item_node_Delete( input_item_node_t *p_node )
+{
+  if(  p_node->p_parent )
+  {
+      for( int i = 0; i < p_node->p_parent->i_children; i++ )
+          if( p_node->p_parent->pp_children[i] == p_node )
+          {
+              REMOVE_ELEM( p_node->p_parent->pp_children,
+                           p_node->p_parent->i_children,
+                           i );
+              break;
+          }
+  }
+
+  RecursiveNodeDelete( p_node );
+}
+
+input_item_node_t *input_item_node_AppendItem( input_item_node_t *p_node, input_item_t *p_item )
+{
+    input_item_node_t *p_new_child = input_item_node_Create( p_item );
+    if( !p_new_child ) return NULL;
+    input_item_node_AppendNode( p_node, p_new_child );
+    return p_new_child;
+}
+
+void input_item_node_AppendNode( input_item_node_t *p_parent, input_item_node_t *p_child )
+{
+    assert( p_parent && p_child && p_child->p_parent == NULL );
+    INSERT_ELEM( p_parent->pp_children,
+                 p_parent->i_children,
+                 p_parent->i_children,
+                 p_child );
+    p_child->p_parent = p_parent;
+}
+
+void input_item_node_PostAndDelete( input_item_node_t *p_root )
+{
+  post_subitems( p_root );
+
+  vlc_event_t event;
+  event.type = vlc_InputItemSubItemTreeAdded;
+  event.u.input_item_subitem_tree_added.p_root = p_root;
+  vlc_event_send( &p_root->p_item->event_manager, &event );
+
+  input_item_node_Delete( p_root );
 }
